@@ -1,5 +1,12 @@
-require "codeclimate-test-reporter"
-CodeClimate::TestReporter.start
+# it throws following message:
+# W, [2018-02-06T18:16:06.360071 #72025]  WARN -- :       This usage of the Code Climate Test Reporter is now deprecated. Since version
+#       1.0, we now require you to run `SimpleCov` in your test/spec helper, and then
+#       run the provided `codeclimate-test-reporter` binary separately to report your
+#       results to Code Climate.
+#
+#       More information here: https://github.com/codeclimate/ruby-test-reporter/blob/master/README.md
+# require "codeclimate-test-reporter"
+# CodeClimate::TestReporter.start
 
 require "simplecov"
 SimpleCov.start do
@@ -8,6 +15,7 @@ end
 
 require "rspec"
 require "timecop"
+require "pp"
 require "fakefs/safe"
 require "fakefs/spec_helpers"
 
@@ -19,7 +27,7 @@ end
 
 def mock_error(subject, message)
   mock_exit do
-    mock(subject).puts("ERROR: #{message}")
+    expect(subject).to receive(:puts).with("ERROR: #{message}")
     yield
   end
 end
@@ -89,6 +97,7 @@ def write_procfile(procfile="Procfile", alpha_env="")
     file.puts "bravo:\t./bravo"
     file.puts "foo_bar:\t./foo_bar"
     file.puts "foo-bar:\t./foo-bar"
+    file.puts "# baz:\t./baz"
   end
   File.expand_path(procfile)
 end
@@ -166,11 +175,9 @@ ensure
 end
 
 RSpec.configure do |config|
-  config.treat_symbols_as_metadata_keys_with_true_values = true
   config.color = true
   config.order = 'rand'
   config.include FakeFS::SpecHelpers, :fakefs
-  config.mock_with :rr
   config.before(:each) do
     FileUtils.mkdir_p('/tmp')
   end
